Crate crate_crypto_internal_peerdas_bls12_381

Crate crate_crypto_internal_peerdas_bls12_381 

Re-exports

pub use ff;
pub use group;

Modules

batch_inversion
fixed_base_msm
lincomb

Constants

G1_POINT_SERIALIZED_SIZE
The number of bytes needed to represent a compressed G1 point
G2_POINT_SERIALIZED_SIZE
The number of bytes needed to represent a compressed G2 point
SCALAR_SERIALIZED_SIZE
The number of bytes needed to represent a scalar

Functions

multi_pairings

Type Aliases

G1Point
G1Projective
G2Point
G2Prepared
G2Projective
KZGCommitment
Scalar